@@ -1,5 +1,5 @@
 use v6;
-class CSS::Module:ver<0.4.4> {
+class CSS::Module:ver<0.4.6> {
     #= a lightweight class for bundling resources associated with a particular CSS Syntax
     has $.name;
     has $.grammar is required;  #| grammar
@@ -9,9 +9,17 @@ class CSS::Module:ver<0.4.4> {
     has CSS::Module %.sub-module;
 
     #| parse an individual property-specific expression
-    method parse-property(Str $property-name, Str $val) {
+    method parse-property(Str $property-name, Str $val, Bool :$warn = True) {
         my $actions = $.actions.new;
         my \p = $.grammar.parse($val, :rule('expr-' ~ $property-name.lc), :$actions );
-        $actions.list(p);
+
+        if p {
+            $actions.list(p);
+        }
+        else {
+            note "unable to parse CSS property '$property-name: $val;'"
+                if $warn;
+            Nil;
+        }
     }
 }
