@@ -1,7 +1,5 @@
 use v6;
 
-class CSS::Module::CSS21::Actions { ... }
-
 use CSS::Specification::Terms::Actions;
 use CSS::Module::CSS21::Spec::Interface;
 use CSS::Module::CSS21::Spec::Actions;
@@ -42,18 +40,6 @@ class CSS::ModuleX::CSS21::Actions
         make $.func( 'rect', $.list($/) );
     }
 
-   # --- Expressions --- #
-
-    method border-style($/)   { make $.list($/) }
-    method border-width($/)   { make $.list($/) }
-    method family-name($/)    { make $<family-name>.ast }
-    method generic-family($/) { make $<keyw>.ast }
-    method absolute-size($/)  { make $<keyw>.ast }
-    method relative-size($/)  { make $<keyw>.ast }
-    method margin-width($/)   { make $.node($/) }
-    method padding-width($/)  { make $.node($/) }
-    method generic-voice($/)  { make $<keyw>.ast }
-    method specific-voice($/) { make $<value>.ast }
 }
 
 class CSS::Module::CSS21::Actions
@@ -63,5 +49,4 @@ class CSS::Module::CSS21::Actions
     does CSS::Module::CSS21::Spec::Interface {
 
     has @._proforma = 'inherit';
-
 }
