@@ -1,7 +1,5 @@
 use v6;
 
-grammar CSS::Module::CSS3::Fonts::AtFontFace {...}
-
 use CSS::Module::CSS3::Fonts::Variants;
 use CSS::Module::CSS3::_Base;
 use CSS::Module::CSS3::Fonts::AtFontFace::Spec::Interface;
@@ -13,11 +11,24 @@ grammar CSS::Module::CSS3::Fonts::AtFontFace
     is CSS::Module::CSS3::_Base
     does CSS::Module::CSS3::Fonts::AtFontFace::Spec::Interface {
 
+    # declare ourselves as a distinct submodule
+    method module {
+        use CSS::Module;
+        # we share the actions class
+        require ::('CSS::Module::CSS3');
+        my $actions = ::('CSS::Module::CSS3::Actions');
+        use CSS::Module::CSS3::Fonts::AtFontFace::Metadata;
+        my %property-metadata = %$CSS::Module::CSS3::Fonts::AtFontFace::Metadata::property;
+        state $this //= CSS::Module.new(
+            :name<@font-face>,
+            :grammar($?CLASS),
+	    :$actions,
+	    :%property-metadata,
+	    );
+    }
     # @font-face declarations
 
     # ---- Functions ----
     rule format {:i('format')'(' [ <string> | <keyw> || <any-args> ] ')'}
     rule local  {:i('local')'(' [ <font-face-name> || <any-args> ] ')'}
-    rule font-face-name { <font-face-name=.identifiers> | <font-face-name=.string> }
-    rule family-name    { <family-name=.identifiers> || <family-name=.string> }
 }
